@@ -50,7 +50,7 @@ class LoanReadContract(Contract):
     interests_paid = MoneyField(max_digits=7, decimal_places=0)
     interests_balance = MoneyField(max_digits=7, decimal_places=0)
     avg_payment = MoneyField(max_digits=7, decimal_places=0)
-    interests_overdue = MoneyField(max_digits=7, decimal_places=0)
+    total_interests_overdue = MoneyField(max_digits=7, decimal_places=0)
 
 
 class PaymentCreateContract(Contract):
