@@ -1,4 +1,4 @@
-__all__ = ('OrderPoint', 'OrderObjectPoint', 'SchedulePoint')
+__all__ = ('OrderPoint', 'OrderObjectPoint', 'SchedulePoint', 'ResendSmsSignPoint')
 
 from djmoney.contrib.django_rest_framework import MoneyField
 from expressmoney.api import *
@@ -50,6 +50,10 @@ class ScheduleReadContract(Contract):
     is_paid = serializers.BooleanField()
 
 
+class ResendSmsSignCreateContract(Contract):
+    pass
+
+
 class OrderID(ID):
     _service = SERVICE
     _app = 'orders'
@@ -62,6 +66,12 @@ class ScheduleID(ID):
     _view_set = 'schedule'
 
 
+class ResendSmsSignPointID(ID):
+    _service = SERVICE
+    _app = 'orders'
+    _view_set = 'resend_sms_sign'
+
+
 class OrderPoint(ListPointMixin, CreatePointMixin, ContractPoint):
     _point_id = OrderID()
     _read_contract = OrderReadContract
@@ -76,3 +86,8 @@ class OrderObjectPoint(RetrievePointMixin, ContractObjectPoint):
 class SchedulePoint(ListPointMixin, ContractPoint):
     _point_id = ScheduleID()
     _read_contract = ScheduleReadContract
+
+
+class ResendSmsSignPoint(CreatePointMixin, ContractPoint):
+    _point_id = ResendSmsSignPointID()
+    _create_contract = ResendSmsSignCreateContract
