@@ -1,5 +1,5 @@
 __all__ = ('LoanPoint', 'LoanObjectPoint', 'ClosedLoanPoint', 'ClosedLoanObjectPoint', 'LoanPaymentPoint',
-           'ExportPoint', 'PartialLoanPaymentPoint', 'ExtendLoanPoint')
+           'ExportPoint', 'PartialLoanPaymentPoint', 'ExtendLoanPoint', 'RestructureLoanPoint',)
 
 from typing import OrderedDict, Union
 
@@ -148,6 +148,35 @@ class PartialPaymentContract(Contract):
     amount = serializers.DecimalField(max_digits=16, decimal_places=0)
 
 
+class RestructureLoanCreateContract(Contract):
+    pass
+
+
+class RestructureLoanReadContract(Contract):
+    ACTIVE = 'ACTIVE'
+    EXPIRED = 'EXPIRED'
+    COMPLETED = 'COMPLETED'
+    CANCELED = 'CANCELED'
+    STATUS_CHOICES = {
+        (ACTIVE, ACTIVE),
+        (EXPIRED, EXPIRED),
+        (COMPLETED, COMPLETED),
+        (CANCELED, CANCELED),
+    }
+    id = serializers.IntegerField(min_value=1)
+    created = serializers.DateTimeField()
+    loan = serializers.IntegerField(min_value=1)
+    status = serializers.ChoiceField(choices=STATUS_CHOICES)
+    start_interests_balance = serializers.DecimalField(max_digits=7, decimal_places=0)
+    restructure_schedules = serializers.ListField()
+
+
+class RestructureLoanID(ID):
+    _service = SERVICE
+    _app = 'loans'
+    _view_set = 'restructure_loan'
+
+
 class LoanID(ID):
     _service = SERVICE
     _app = 'loans'
@@ -232,3 +261,9 @@ class ExtendLoanPoint(CreatePointMixin, ContractPoint):
 class PartialLoanPaymentPoint(CreatePointMixin, ContractPoint):
     _point_id = PartialPaymentID()
     _create_contract = PartialPaymentContract
+
+
+class RestructureLoanPoint(CreatePointMixin, ListPointMixin, ContractPoint):
+    _point_id = RestructureLoanID()
+    _create_contract = RestructureLoanCreateContract
+    _read_contract = RestructureLoanReadContract
