@@ -1,7 +1,8 @@
-__all__ = ('UnderwritingTaskPoint', 'BankCardProcessPoint')
+__all__ = ('UnderwritingTaskPoint', 'BankCardProcessPoint', 'AntifraudProcessPoint')
 from expressmoney.api import *
 
 SERVICE = 'profiles'
+APP = 'underwriting'
 
 
 class UnderwritingTaskCreateContract(Contract):
@@ -13,18 +14,28 @@ class BankCardProcessCreateContract(Contract):
     file = serializers.CharField(max_length=256)
 
 
+class AntifraudProcessCreateContract(Contract):
+    comment = serializers.CharField(max_length=1024)
+
+
 class UnderwritingTaskID(ID):
     _service = SERVICE
-    _app = 'underwriting'
+    _app = APP
     _view_set = 'underwriting_task'
 
 
 class BankCardProcessID(ID):
     _service = SERVICE
-    _app = 'underwriting'
+    _app = APP
     _view_set = 'bank_card_process'
 
 
+class AntifraudProcessID(ID):
+    _service = SERVICE
+    _app = APP
+    _view_set = 'antifraudprocess'
+
+
 class UnderwritingTaskPoint(CreatePointMixin, ContractPoint):
     _point_id = UnderwritingTaskID()
     _create_contract = UnderwritingTaskCreateContract
@@ -33,3 +44,8 @@ class UnderwritingTaskPoint(CreatePointMixin, ContractPoint):
 class BankCardProcessPoint(CreatePointMixin, ContractPoint):
     _point_id = BankCardProcessID()
     _create_contract = BankCardProcessCreateContract
+
+
+class AntifraudProcessPoint(CreatePointMixin, ContractPoint):
+    _point_id = AntifraudProcessID()
+    _create_contract = AntifraudProcessCreateContract
